@@ -1,6 +1,7 @@
 const char *usage_msg[] = {
-	"  -a: append to ALF file.",
-	"  -A: convert EOLs and tabs in all input files.",
+	"  -A: append to ALF file.",
+	"  -a: convert EOLs and tabs in text files.",
+	"  -aa: convert EOLs and tabs in all input files.",
 	"  -h: show this help message.",
 	"  -o: overwrite ALF file if it exists (don't create file~ backup).",
 	"  -q: quiet.",
