@@ -185,9 +185,12 @@ void extract_alf(void) {
 		new_file = 1;
 		uncrunch_file();
 		if(bad_checksum) bad_checksum_count++;
-		if(bytes_written != getquad(alf_hdr_origsize0))
-			fprintf(stderr, "%s: %s should be %u bytes, but extracted to %u.\n",
-					self, out_filename, getquad(alf_hdr_origsize0), bytes_written);
+		if(bytes_written != getquad(alf_hdr_origsize0)) {
+			fprintf(stderr, "%s: ", self);
+			safe_print_filename(out_filename, stderr);
+			fprintf(stderr, " should be %u bytes, but extracted to %u.\n",
+					getquad(alf_hdr_origsize0), bytes_written);
+		}
 
 		if(!opts.extract_to_stdout) {
 			fclose(out_file);
@@ -209,11 +212,16 @@ void extract_alf(void) {
 	if(!opts.quiet && !files_extracted) {
 		printf("No files %s!\n", opts.testonly ? "tested" : "extracted");
 	}
+
+	if(!opts.quiet)
+		puts("Processing complete");
 }
 
 void chksum_err(void) {
 	bad_checksum = 1;
-	fprintf(stderr, "%s: checksum error on %s\n", self, out_filename);
+	fprintf(stderr, "%s: checksum error on ", self);
+	safe_print_filename(out_filename, stderr);
+	fputc('\n', stderr);
 }
 
 void truncated_err(void){
