@@ -9,12 +9,15 @@ const char *usage_msg[] = {
 	"  -k: keep trailing periods (dots) in filenames.",
 	"  -l: list files in archive (filenames only).",
 	"  -L: use lowercase filenames.",
+	"  -n: extract only file #<number> (counting from 1).",
 	"  -o: overwrite files (do not create file~ backups).",
 	"  -p: extract to stdout (enables -q).",
 	"  -q: quiet: don't print filenames during extraction/testing.",
+	"  -s: split ALF file into multiple ALFs.",
 	"  -t: test archive.",
 	"  -v: verbose listing of archive contents.",
 	"  -V: show version number.",
 	"  -x: exclude <wildcard>. may be given multiple times.",
+	"  --: end of options (next arg is alf-file).",
 	(const char*)0
 };
